if [ -x /usr/bin/gtk-update-icon-cache.exe ]
then
    /usr/bin/gtk-update-icon-cache --force /usr/share/icons/hicolor
fi

/usr/bin/glib-compile-schemas /usr/share/glib-2.0/schemas

/usr/bin/update-desktop-database /usr/share/applications
/usr/bin/update-mime-database -n /usr/share/mime

